@@ -5,17 +5,27 @@ from typing import Union
 
 from anndata import AnnData
 
+
 def file_10x_h5(
     filename: Union[str, Path],
 ) -> AnnData:
-    """
+
+    """\
     Wrap function scanpy.read_10x_h5
+    Read 10x-Genomics-formatted hdf5 file.
+
+    Parameters
+    ----------
+    filename
+        Path to the h5 file.
+    Returns
+    -------
+    AnnData
     """
 
-    from stlearn.external.scanpy.readwrite import read_10x_h5
+    from scanpy.readwrite import read_10x_h5
 
     adata = read_10x_h5(filename)
-    
 
     return adata
 
@@ -23,11 +33,20 @@ def file_10x_h5(
 def file_10x_mtx(
     filename: Union[str, Path],
 ) -> AnnData:
-    """
+    """\
     Wrap function scanpy.read_10x_mtx
+    Read .mtx file.
+
+    Parameters
+    ----------
+    filename
+        Path to the h5 file.
+    Returns
+    -------
+    AnnData
     """
 
-    from stlearn.external.scanpy.readwrite import read_10x_mtx
+    from scanpy.readwrite import read_10x_mtx
 
     adata = read_10x_mtx(filename)
 
@@ -39,10 +58,19 @@ def file_table(
 ) -> AnnData:
     """
     Wrap function scanpy.read
+    Read file and return AnnData object.
+
+    Parameters
+    ----------
+    filename
+        Path to the h5 file.
+    Returns
+    -------
+    AnnData
     """
 
-    from stlearn.external.scanpy.readwrite import read
+    from scanpy.readwrite import read
 
     adata = read(filename)
 
-    return adata
\ No newline at end of file
+    return adata
